@@ -1,6 +1,130 @@
 # Num6
 
-from .charlib import *
+# from .charlib import *
+
+
+# Character Library
+
+# Upper Case
+_A = '233223'
+_B = '332232'
+_C = '323232'
+_D = '322322'
+_E = '323323'
+_F = '322233'
+_G = '222332'
+_H = '322223'
+_I = '244244'
+_J = '442442'
+_K = '424242'
+_L = '444422'
+_M = '224224'
+_N = '422424'
+_O = '244442'
+_P = '444442'
+_Q = '244242'
+_R = '255225'
+_S = '552255'
+_T = '525252'
+_U = '552552'
+_V = '522552'
+_W = '225225'
+_X = '522525'
+_Y = '255552'
+_Z = '255252'
+
+
+# Lower Case
+_a = '101010'
+_b = '101011'
+_c = '101001'
+_d = '101000'
+_e = '110011'
+_f = '110100'
+_g = '110010'
+_h = '202020'
+_i = '220022'
+_j = '200220'
+_k = '222220'
+_l = '202202'
+_m = '222000'
+_n = '300033'
+_o = '330330'
+_p = '333303'
+_q = '300333'
+_r = '033033'
+_s = '003300'
+_t = '033030'
+_u = '444400'
+_v = '404040'
+_w = '440440'
+_x = '404404'
+_y = '044004'
+_z = '004400'
+
+
+# Numbers
+_one = '122111'
+_two = '112212'
+_three = '211222'
+_four = '212212'
+_five = '112112'
+_six = '133133'
+_seven = '131133'
+_eight = '313311'
+_nine = '331133'
+_zero = '333133'
+
+# Spacial Character
+_dot = '000000'  # .
+_space = '000010'
+_comma = '000001'  # ,
+_star = '000011'  # *
+_fslash = '111111'  # /
+_bslash = '222222'  # \
+_at = '121212'  # @
+_amp = '100011'  # &
+_persent = '011000'  # %
+_dash = '100000'  # -
+_unders = '100110'  # _
+_excla = '211221'  # !
+_question = '313131'  # ?
+_squort = '333333'  # '
+_dquort = '444444'  # "
+_sbparen = '010111'  # (
+_cbparen = '212211'  # )
+_sbsqure = '313133'  # [
+_cbsqure = '232323'  # ]
+_sbmid = '332233'  # {
+_cbmid = '323222'  # }
+_plas = '121111'  # +
+_colon = '131131'  # :
+_ssep = '211111'  # <
+_csep = '121112'  # >
+_scolon = '131333'  # ;
+_cross = '202021'  # ×
+_pii = '221121'  # π
+_copy = '777777'  # ©
+_rr = '414411'  # ®
+_root = '224422'  # √
+_dollerS = '666666'  # $
+_hashs  = '616666' # #
+_aequal = '661166'  # ~
+_hdash = '616161'  # `
+_degree = '661661'  # °
+_vag = '611166'  # ÷
+_hTM = '661111'  # ™
+_equal = '661666'  # =
+_nequal = '166611'  # ≠
+_alequal = '116116'  # ≈
+_song = '116661'  # ♪
+_ll = '111666'  # |
+_powerof = '161666'  # ^
+_dS = '616166'  # £
+_tab = '661161'  # \t
+_newL = '676767'  # \n
+
+
 
 # encrypter
 
